Crate uv_cli

Crate uv_cli 

Modules

comma
compat
options
version
Code for representing uv’s release version number.

Structs

AddArgs
AuditArgs
AuthDirArgs
AuthHelperArgs
AuthLoginArgs
AuthLogoutArgs
AuthNamespace
AuthTokenArgs
BuildArgs
BuildIsolationArgs
Arguments that configure build isolation for source distributions.
BuildOptionsArgs
CacheNamespace
CheckArgs
CleanArgs
Cli
CompileBytecodeArgs
DisplayTreeArgs
ExcludeNewerArgs
Arguments that filter packages by upload date.
ExportArgs
FetchArgs
Arguments that are used by commands that need to fetch from the Simple API.
FormatArgs
GenerateShellCompletionArgs
GlobalArgs
HashCheckingArgs
Arguments that configure requirement hash checking.
HelpArgs
IndexArgs
InitArgs
InstallerArgs
Arguments that are used by commands that need to install (but not resolve) packages.
LockArgs
MetadataArgs
PackageBuildIsolationArgs
Arguments that configure global and package-specific build isolation.
PackageExcludeNewerArgs
Arguments that filter packages by global and package-specific upload dates.
PipCheckArgs
PipCompileArgs
PipDebugArgs
PipFreezeArgs
PipInstallArgs
PipListArgs
PipNamespace
PipShowArgs
PipSyncArgs
PipTreeArgs
PipUninstallArgs
PruneArgs
PublishArgs
PythonDirArgs
PythonFindArgs
PythonInstallArgs
PythonInstallCompileBytecodeArgs
PythonListArgs
PythonNamespace
PythonPinArgs
PythonUninstallArgs
PythonUpgradeArgs
RefreshArgs
RegistryClientArgs
Arguments that configure the package registry client.
ReinstallArgs
RemoveArgs
ResolverArgs
Arguments that are used by commands that need to resolve (but not install) packages.
ResolverInstallerArgs
Arguments that are used by commands that need to resolve and install packages.
RunArgs
SelfNamespace
SelfUpdateArgs
SizeArgs
SourcesArgs
Arguments that control dependency sources.
SyncArgs
ToolDirArgs
ToolInstallArgs
ToolListArgs
ToolNamespace
ToolRunArgs
ToolUninstallArgs
ToolUpgradeArgs
TopLevelArgs
TreeArgs
UpgradeArgs
UvxArgs
VenvArgs
VersionArgs
VersionBumpSpec
VersionBumpSpecValueParser
VersionSelectionArgs
Arguments that configure package version selection.
WorkspaceDirArgs
WorkspaceListArgs
WorkspaceNamespace

Enums

AuditOutputFormat
AuthCommand
AuthHelperCommand
AuthHelperProtocol
Credential helper protocols supported by uv
AuthorFrom
BuildBackendCommand
See PEP 517 and PEP 660 for specifications of the parameters.
CacheCommand
ColorChoice
Commands
ExternalCommand
ListFormat
Maybe
A re-implementation of Option, used to avoid Clap’s automatic Option flattening in [parse_index_url].
PipCommand
ProjectCommand
PythonCommand
PythonListFormat
SelfCommand
SyncFormat
ToolCommand
TreeFormat
VersionBump
VersionFormat
WorkspaceCommand