pub struct AuditArgs {Show 15 fields
pub no_extra: Vec<ExtraName>,
pub no_dev: bool,
pub no_group: Vec<GroupName>,
pub no_default_groups: bool,
pub only_group: Vec<GroupName>,
pub only_dev: bool,
pub locked: bool,
pub frozen: bool,
pub build: BuildOptionsArgs,
pub resolver: ResolverArgs,
pub script: Option<PathBuf>,
pub python_version: Option<PythonVersion>,
pub python_platform: Option<TargetTriple>,
pub service_format: VulnerabilityServiceFormat,
pub service_url: Option<String>,
}Fields
no_extra: Vec<ExtraName>Don’t audit the specified optional dependencies.
May be provided multiple times.
no_dev: boolDon’t audit the development dependency group [env: UV_NO_DEV=]
This option is an alias of --no-group dev.
See --no-default-groups to exclude all default groups instead.
This option is only available when running in a project.
no_group: Vec<GroupName>Don’t audit the specified dependency group.
May be provided multiple times.
no_default_groups: boolDon’t audit the default dependency groups.
only_group: Vec<GroupName>Only audit dependencies from the specified dependency group.
The project and its dependencies will be omitted.
May be provided multiple times. Implies --no-default-groups.
only_dev: boolOnly audit the development dependency group.
The project and its dependencies will be omitted.
This option is an alias for --only-group dev. Implies --no-default-groups.
locked: boolAssert that the uv.lock will remain unchanged [env: UV_LOCKED=]
Requires that the lockfile is up-to-date. If the lockfile is missing or needs to be updated, uv will exit with an error.
frozen: boolAudit the requirements without locking the project [env: UV_FROZEN=]
If the lockfile is missing, uv will exit with an error.
build: BuildOptionsArgsresolver: ResolverArgsscript: Option<PathBuf>Audit the specified PEP 723 Python script, rather than the current project.
The specified script must be locked, i.e. with uv lock --script <script>
before it can be audited.
python_version: Option<PythonVersion>The Python version to use when auditing.
For example, pass --python-version 3.10 to audit the dependencies that would be included
when installing on Python 3.10.
Defaults to the version of the discovered Python interpreter.
python_platform: Option<TargetTriple>The platform to use when auditing.
For example, pass --platform windows to audit the dependencies that would be included
when installing on Windows.
Represented as a “target triple”, a string that describes the target platform in terms of
its CPU, vendor, and operating system name, like x86_64-unknown-linux-gnu or
aarch64-apple-darwin.
service_format: VulnerabilityServiceFormatThe service format to use for vulnerability lookups.
Each service format has a default URL, which can be
changed with --service-url. The defaults are:
- OSV: https://api.osv.dev/
service_url: Option<String>The URL to vulnerability service API endpoint.
If not provided, the default URL for the selected service will be used.
The service needs to use the OSV protocol, unless a different
format was requested by --service-format.