pub struct AuditCommonArgs {
pub output_format: AuditOutputFormat,
pub ignore: Vec<String>,
pub ignore_until_fixed: Vec<String>,
pub service_format: VulnerabilityServiceFormat,
pub service_url: Option<DisplaySafeUrl>,
}Fields
output_format: AuditOutputFormatSelect the output format.
ignore: Vec<String>Ignore a vulnerability by ID.
Vulnerabilities matching any of the provided IDs (including aliases) will be excluded from the audit results.
May be provided multiple times.
ignore_until_fixed: Vec<String>Ignore a vulnerability by ID, but only while no fix is available.
Vulnerabilities matching any of the provided IDs (including aliases) will be excluded from the audit results as long as they have no known fix versions. Once a fix version becomes available, the vulnerability will be reported again.
May be provided multiple times.
service_format: VulnerabilityServiceFormatThe service format to use for vulnerability lookups.
Each service format has a default URL, which can be
changed with --service-url. The defaults are:
- OSV: https://api.osv.dev/
service_url: Option<DisplaySafeUrl>The URL to vulnerability service API endpoint.
If not provided, the default URL for the selected service will be used.
The service needs to use the OSV protocol, unless a different
format was requested by --service-format.