pub struct ExcludeNewerArgs {
pub exclude_newer: Option<ExcludeNewerOverride>,
}Expand description
Arguments that filter packages by upload date.
Fields
exclude_newer: Option<ExcludeNewerOverride>Limit candidate packages to those that were uploaded prior to the given date.
The date is compared against the upload time of each individual distribution artifact (i.e., when each file was uploaded to the package index), not the release date of the package version.
Accepts RFC 3339 timestamps (e.g., 2006-12-02T02:07:43Z), local dates in the same format
(e.g., 2006-12-02) resolved based on your system’s configured time zone, a “friendly”
duration (e.g., 24 hours, 1 week, 30 days), or an ISO 8601 duration (e.g., PT24H,
P7D, P30D).
Durations do not respect semantics of the local time zone and are always resolved to a fixed number of seconds assuming that a day is 24 hours (e.g., DST transitions are ignored). Calendar units such as months and years are not allowed.
Use false to disable exclude-newer.