pub struct FormatArgs {
pub check: bool,
pub diff: bool,
pub version: Option<String>,
pub exclude_newer: Option<ExcludeNewerValue>,
pub extra_args: Vec<String>,
pub no_project: bool,
pub show_version: bool,
}Fields
check: boolCheck if files are formatted without applying changes.
diff: boolShow a diff of formatting changes without applying them.
Implies --check.
version: Option<String>The version of Ruff to use for formatting.
Accepts either a version (e.g., 0.8.2) which will be treated as an exact pin,
a version specifier (e.g., >=0.8.0), or latest to use the latest available version.
By default, a constrained version range of Ruff will be used (e.g., >=0.15,<0.16).
exclude_newer: Option<ExcludeNewerValue>Limit candidate Ruff versions to those released prior to the given date.
Accepts a superset of RFC 3339 (e.g.,
2006-12-02T02:07:43Z) or local date in the same format (e.g. 2006-12-02), as well as
durations relative to “now” (e.g., -1 week).
extra_args: Vec<String>Additional arguments to pass to Ruff.
For example, use uv format -- --line-length 100 to set the line length or
uv format -- src/module/foo.py to format a specific file.
no_project: boolAvoid discovering a project or workspace.
Instead of running the formatter in the context of the current project, run it in the context of the current directory. This is useful when the current directory is not a project.
show_version: boolDisplay the version of Ruff that will be used for formatting.
This is useful for verifying which version was resolved when using version constraints
(e.g., --version ">=0.8.0") or --version latest.