pub struct MetadataArgs {
pub locked: bool,
pub frozen: bool,
pub dry_run: bool,
pub resolver: ResolverArgs,
pub build: BuildOptionsArgs,
pub refresh: RefreshArgs,
pub python: Option<Maybe<String>>,
}Fields
locked: boolCheck if the lockfile is up-to-date [env: UV_LOCKED=]
Asserts that the uv.lock would remain unchanged after a resolution. If the lockfile is
missing or needs to be updated, uv will exit with an error.
frozen: boolAssert that a uv.lock exists without checking if it is up-to-date [env: UV_FROZEN=]
dry_run: boolPerform a dry run, without writing the lockfile.
In dry-run mode, uv will resolve the project’s dependencies and report on the resulting changes, but will not write the lockfile to disk.
resolver: ResolverArgsbuild: BuildOptionsArgsrefresh: RefreshArgspython: Option<Maybe<String>>The Python interpreter to use during resolution.
A Python interpreter is required for building source distributions to determine package metadata when there are not wheels.
The interpreter is also used as the fallback value for the minimum Python version if
requires-python is not set.
See uv help python for details on Python discovery and supported request formats.