pub struct PackageExcludeNewerArgs {
pub exclude_newer: ExcludeNewerArgs,
pub exclude_newer_package: Option<Vec<ExcludeNewerPackageEntry>>,
}Expand description
Arguments that filter packages by global and package-specific upload dates.
Fields
exclude_newer: ExcludeNewerArgsexclude_newer_package: Option<Vec<ExcludeNewerPackageEntry>>Limit candidate packages for specific packages to those that were uploaded prior to the given date.
Accepts package-date pairs in the format PACKAGE=DATE, where DATE is an RFC 3339
timestamp (e.g., 2006-12-02T02:07:43Z), a local date in the same format (e.g.,
2006-12-02) resolved based on your system’s configured time zone, a “friendly” duration
(e.g., 24 hours, 1 week, 30 days), or an ISO 8601 duration (e.g., PT24H, P7D,
P30D).
Durations do not respect semantics of the local time zone and are always resolved to a fixed number of seconds assuming that a day is 24 hours (e.g., DST transitions are ignored). Calendar units such as months and years are not allowed.
Can be provided multiple times for different packages.