pub struct ResolverInstallerArgs {Show 15 fields
pub index_args: IndexArgs,
pub upgrade: bool,
pub no_upgrade: bool,
pub upgrade_package: Vec<Requirement<VerbatimParsedUrl>>,
pub upgrade_group: Vec<GroupName>,
pub reinstall: ReinstallArgs,
pub registry_client: RegistryClientArgs,
pub version_selection: VersionSelectionArgs,
pub config_setting: Option<Vec<ConfigSettingEntry>>,
pub config_settings_package: Option<Vec<ConfigSettingPackageEntry>>,
pub build_isolation: PackageBuildIsolationArgs,
pub exclude_newer: PackageExcludeNewerArgs,
pub link_mode: Option<LinkMode>,
pub compile_bytecode: CompileBytecodeArgs,
pub sources: SourcesArgs,
}Expand description
Arguments that are used by commands that need to resolve and install packages.
Fields
index_args: IndexArgsupgrade: boolAllow package upgrades, ignoring pinned versions in any existing output file. Implies
--refresh.
no_upgrade: boolupgrade_package: Vec<Requirement<VerbatimParsedUrl>>Allow upgrades for a specific package, ignoring pinned versions in any existing output file.
Implies --refresh-package.
upgrade_group: Vec<GroupName>Allow upgrades for all packages in a dependency group, ignoring pinned versions in any existing output file.
reinstall: ReinstallArgsregistry_client: RegistryClientArgsversion_selection: VersionSelectionArgsconfig_setting: Option<Vec<ConfigSettingEntry>>Settings to pass to the PEP 517 build backend, specified as KEY=VALUE pairs.
config_settings_package: Option<Vec<ConfigSettingPackageEntry>>Settings to pass to the PEP 517 build backend for a specific package, specified as PACKAGE:KEY=VALUE pairs.
build_isolation: PackageBuildIsolationArgsexclude_newer: PackageExcludeNewerArgslink_mode: Option<LinkMode>The method to use when installing packages from the global cache.
Defaults to clone (also known as Copy-on-Write) on macOS and Linux, and hardlink on
Windows.
WARNING: The use of symlink link mode is discouraged, as they create tight coupling between
the cache and the target environment. For example, clearing the cache (uv cache clean)
will break all installed packages by way of removing the underlying source files. Use
symlinks with caution.
compile_bytecode: CompileBytecodeArgssources: SourcesArgsTrait Implementations
Sourceimpl Args for ResolverInstallerArgs
impl Args for ResolverInstallerArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for ResolverInstallerArgs
impl FromArgMatches for ResolverInstallerArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourceimpl TryFrom<ResolverInstallerArgs> for PipOptions
impl TryFrom<ResolverInstallerArgs> for PipOptions