pub struct ToolListArgs {
pub show_paths: bool,
pub show_version_specifiers: bool,
pub show_with: bool,
pub show_extras: bool,
pub show_python: bool,
pub outdated: bool,
pub no_outdated: bool,
pub exclude_newer: Option<ExcludeNewerValue>,
pub python_preference: Option<PythonPreference>,
pub no_python_downloads: bool,
}Fields
show_paths: boolWhether to display the path to each tool environment and installed executable.
show_version_specifiers: boolWhether to display the version specifier(s) used to install each tool.
show_with: boolWhether to display the additional requirements installed with each tool.
show_extras: boolWhether to display the extra requirements installed with each tool.
show_python: boolWhether to display the Python version associated with each tool.
outdated: boolList outdated tools.
The latest version of each tool will be shown alongside the installed version. Up-to-date tools will be omitted from the output.
no_outdated: boolexclude_newer: Option<ExcludeNewerValue>Limit candidate packages to those that were uploaded prior to the given date.
Accepts RFC 3339 timestamps (e.g., 2006-12-02T02:07:43Z), local dates in the same format
(e.g., 2006-12-02) resolved based on your system’s configured time zone, a “friendly”
duration (e.g., 24 hours, 1 week, 30 days), or an ISO 8601 duration (e.g., PT24H,
P7D, P30D).
Durations do not respect semantics of the local time zone and are always resolved to a fixed number of seconds assuming that a day is 24 hours (e.g., DST transitions are ignored). Calendar units such as months and years are not allowed.
python_preference: Option<PythonPreference>no_python_downloads: boolTrait Implementations
Sourceimpl Args for ToolListArgs
impl Args for ToolListArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for ToolListArgs
impl FromArgMatches for ToolListArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Auto Trait Implementations
impl Freeze for ToolListArgs
impl RefUnwindSafe for ToolListArgs
impl Send for ToolListArgs
impl Sync for ToolListArgs
impl Unpin for ToolListArgs
impl UnsafeUnpin for ToolListArgs
impl UnwindSafe for ToolListArgs