pub struct ToolUpgradeArgs {Show 19 fields
pub name: Vec<String>,
pub all: bool,
pub python: Option<Maybe<String>>,
pub python_platform: Option<TargetTriple>,
pub upgrade: bool,
pub upgrade_package: Vec<Requirement<VerbatimParsedUrl>>,
pub upgrade_group: Vec<GroupName>,
pub index_args: IndexArgs,
pub reinstall: ReinstallArgs,
pub registry_client: RegistryClientArgs,
pub version_selection: VersionSelectionArgs,
pub config_setting: Option<Vec<ConfigSettingEntry>>,
pub config_setting_package: Option<Vec<ConfigSettingPackageEntry>>,
pub build_isolation: PackageBuildIsolationArgs,
pub exclude_newer: PackageExcludeNewerArgs,
pub link_mode: Option<LinkMode>,
pub compile_bytecode: CompileBytecodeArgs,
pub sources: SourcesArgs,
pub build: BuildOptionsArgs,
}Fields
name: Vec<String>The name of the tool to upgrade, along with an optional version specifier.
all: boolUpgrade all tools.
python: Option<Maybe<String>>Upgrade a tool, and specify it to use the given Python interpreter to build its environment.
Use with --all to apply to all tools.
See uv help python for details on Python discovery and supported request formats.
python_platform: Option<TargetTriple>The platform for which requirements should be installed.
Represented as a “target triple”, a string that describes the target platform in terms of
its CPU, vendor, and operating system name, like x86_64-unknown-linux-gnu or
aarch64-apple-darwin.
When targeting macOS (Darwin), the default minimum version is 13.0. Use
MACOSX_DEPLOYMENT_TARGET to specify a different minimum version, e.g., 14.0.
When targeting iOS, the default minimum version is 13.0. Use
IPHONEOS_DEPLOYMENT_TARGET to specify a different minimum version, e.g., 14.0.
When targeting Android, the default minimum Android API level is 24. Use
ANDROID_API_LEVEL to specify a different minimum version, e.g., 26.
WARNING: When specified, uv will select wheels that are compatible with the target
platform; as a result, the installed distributions may not be compatible with the current
platform. Conversely, any distributions that are built from source may be incompatible with
the target platform, as they will be built for the current platform. The
--python-platform option is intended for advanced use cases.
upgrade: boolAllow package upgrades, ignoring pinned versions in any existing output file. Implies
--refresh.
upgrade_package: Vec<Requirement<VerbatimParsedUrl>>Allow upgrades for a specific package, ignoring pinned versions in any existing output
file. Implies --refresh-package.
upgrade_group: Vec<GroupName>Allow upgrades for all packages in a dependency group, ignoring pinned versions in any existing output file.
index_args: IndexArgsreinstall: ReinstallArgsregistry_client: RegistryClientArgsversion_selection: VersionSelectionArgsconfig_setting: Option<Vec<ConfigSettingEntry>>Settings to pass to the PEP 517 build backend, specified as KEY=VALUE pairs.
config_setting_package: Option<Vec<ConfigSettingPackageEntry>>Settings to pass to the PEP 517 build backend for a specific package, specified as PACKAGE:KEY=VALUE pairs.
build_isolation: PackageBuildIsolationArgsexclude_newer: PackageExcludeNewerArgslink_mode: Option<LinkMode>The method to use when installing packages from the global cache.
Defaults to clone (also known as Copy-on-Write) on macOS and Linux, and hardlink on
Windows.
WARNING: The use of symlink link mode is discouraged, as they create tight coupling between
the cache and the target environment. For example, clearing the cache (uv cache clean)
will break all installed packages by way of removing the underlying source files. Use
symlinks with caution.
compile_bytecode: CompileBytecodeArgssources: SourcesArgsbuild: BuildOptionsArgsTrait Implementations
Sourceimpl Args for ToolUpgradeArgs
impl Args for ToolUpgradeArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for ToolUpgradeArgs
impl FromArgMatches for ToolUpgradeArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Auto Trait Implementations
impl !Freeze for ToolUpgradeArgs
impl RefUnwindSafe for ToolUpgradeArgs
impl Send for ToolUpgradeArgs
impl Sync for ToolUpgradeArgs
impl Unpin for ToolUpgradeArgs
impl UnsafeUnpin for ToolUpgradeArgs
impl UnwindSafe for ToolUpgradeArgs