pub struct AuditArgs {Show 19 fields
pub extra: Option<Vec<ExtraName>>,
pub all_extras: bool,
pub no_extra: Vec<ExtraName>,
pub no_all_extras: bool,
pub dev: bool,
pub no_dev: bool,
pub group: Vec<GroupName>,
pub no_group: Vec<GroupName>,
pub no_default_groups: bool,
pub only_group: Vec<GroupName>,
pub all_groups: bool,
pub only_dev: bool,
pub locked: bool,
pub frozen: bool,
pub build: BuildOptionsArgs,
pub resolver: ResolverArgs,
pub script: Option<PathBuf>,
pub python_version: Option<PythonVersion>,
pub python_platform: Option<TargetTriple>,
}Fields
extra: Option<Vec<ExtraName>>Include optional dependencies from the specified extra name.
May be provided more than once.
This option is only available when running in a project.
all_extras: boolInclude all optional dependencies.
Optional dependencies are defined via project.optional-dependencies in a pyproject.toml.
This option is only available when running in a project.
no_extra: Vec<ExtraName>Exclude the specified optional dependencies, if --all-extras is supplied.
May be provided multiple times.
no_all_extras: booldev: boolInclude the development dependency group [env: UV_DEV=]
Development dependencies are defined via dependency-groups.dev or
tool.uv.dev-dependencies in a pyproject.toml.
This option is an alias for --group dev.
This option is only available when running in a project.
no_dev: boolDisable the development dependency group [env: UV_NO_DEV=]
This option is an alias of --no-group dev.
See --no-default-groups to disable all default groups instead.
This option is only available when running in a project.
group: Vec<GroupName>Include dependencies from the specified dependency group.
May be provided multiple times.
no_group: Vec<GroupName>Disable the specified dependency group.
This option always takes precedence over default groups,
--all-groups, and --group.
May be provided multiple times.
no_default_groups: boolIgnore the default dependency groups.
uv includes the groups defined in tool.uv.default-groups by default.
This disables that option, however, specific groups can still be included with --group.
only_group: Vec<GroupName>Only include dependencies from the specified dependency group.
The project and its dependencies will be omitted.
May be provided multiple times. Implies --no-default-groups.
all_groups: boolInclude dependencies from all dependency groups.
--no-group can be used to exclude specific groups.
only_dev: boolOnly include the development dependency group.
The project and its dependencies will be omitted.
This option is an alias for --only-group dev. Implies --no-default-groups.
locked: boolAssert that the uv.lock will remain unchanged [env: UV_LOCKED=]
Requires that the lockfile is up-to-date. If the lockfile is missing or needs to be updated, uv will exit with an error.
frozen: boolAudit the requirements without locking the project [env: UV_FROZEN=]
If the lockfile is missing, uv will exit with an error.
build: BuildOptionsArgsresolver: ResolverArgsscript: Option<PathBuf>Audit the specified PEP 723 Python script, rather than the current project.
The specified script must be locked, i.e. with uv lock --script <script>
before it can be audited.
python_version: Option<PythonVersion>The Python version to use when auditing.
For example, pass --python-version 3.10 to audit the dependencies that would be included
when installing on Python 3.10.
Defaults to the version of the discovered Python interpreter.
python_platform: Option<TargetTriple>The platform to use when auditing.
For example, pass --platform windows to audit the dependencies that would be included
when installing on Windows.
Represented as a “target triple”, a string that describes the target platform in terms of
its CPU, vendor, and operating system name, like x86_64-unknown-linux-gnu or
aarch64-apple-darwin.