pub struct CheckArgs {Show 21 fields
pub extra: Option<Vec<ExtraName>>,
pub all_extras: bool,
pub no_extra: Vec<ExtraName>,
pub no_all_extras: bool,
pub dev: bool,
pub no_dev: bool,
pub only_dev: bool,
pub group: Vec<GroupName>,
pub no_group: Vec<GroupName>,
pub no_default_groups: bool,
pub only_group: Vec<GroupName>,
pub all_groups: bool,
pub locked: bool,
pub frozen: bool,
pub no_sync: bool,
pub python: Option<Maybe<String>>,
pub ty_version: Option<String>,
pub no_project: bool,
pub installer: ResolverInstallerArgs,
pub build: BuildOptionsArgs,
pub refresh: RefreshArgs,
}Fields
extra: Option<Vec<ExtraName>>Include optional dependencies from the specified extra name.
May be provided more than once.
When multiple extras or groups are specified that appear in tool.uv.conflicts, uv will
report an error.
Note that all optional dependencies are always included in the resolution; this option only affects the selection of packages to install.
all_extras: boolInclude all optional dependencies.
When two or more extras are declared as conflicting in tool.uv.conflicts, using this flag
will always result in an error.
Note that all optional dependencies are always included in the resolution; this option only affects the selection of packages to install.
no_extra: Vec<ExtraName>Exclude the specified optional dependencies, if --all-extras is supplied.
May be provided multiple times.
no_all_extras: booldev: boolInclude the development dependency group [env: UV_DEV=]
This option is an alias for --group dev.
no_dev: boolDisable the development dependency group [env: UV_NO_DEV=]
This option is an alias of --no-group dev.
See --no-default-groups to disable all default groups instead.
only_dev: boolOnly include the development dependency group.
The project and its dependencies will be omitted.
This option is an alias for --only-group dev. Implies --no-default-groups.
group: Vec<GroupName>Include dependencies from the specified dependency group.
When multiple extras or groups are specified that appear in
tool.uv.conflicts, uv will report an error.
May be provided multiple times.
no_group: Vec<GroupName>Disable the specified dependency group [env: UV_NO_GROUP=]
This option always takes precedence over default groups,
--all-groups, and --group.
May be provided multiple times.
no_default_groups: boolIgnore the default dependency groups.
uv includes the groups defined in tool.uv.default-groups by default.
This disables that option, however, specific groups can still be included with --group.
only_group: Vec<GroupName>Only include dependencies from the specified dependency group.
The project and its dependencies will be omitted.
May be provided multiple times. Implies --no-default-groups.
all_groups: boolInclude dependencies from all dependency groups.
--no-group can be used to exclude specific groups.
locked: boolAssert that the uv.lock will remain unchanged [env: UV_LOCKED=]
Requires that the lockfile is up-to-date. If the lockfile is missing or needs to be updated, uv will exit with an error.
frozen: boolSync without updating the uv.lock file [env: UV_FROZEN=]
Instead of checking if the lockfile is up-to-date, uses the versions in the lockfile as the
source of truth. If the lockfile is missing, uv will exit with an error. If the
pyproject.toml includes changes to dependencies that have not been included in the
lockfile yet, they will not be present in the environment.
no_sync: boolAvoid syncing the virtual environment [env: UV_NO_SYNC=]
Implies --frozen, as the project dependencies will be ignored (i.e., the lockfile will not
be updated, since the environment will not be synced regardless).
python: Option<Maybe<String>>The Python interpreter to use for the project environment.
By default, the first interpreter that meets the project’s
requires-python constraint is used.
See uv python for more details on Python discovery and requests.
ty_version: Option<String>The version of ty to use for type checking.
Accepts either a version (e.g., 0.0.1) which will be treated as an exact pin,
a version specifier (e.g., >=0.0.1), or latest to use the latest available version.
By default, a constrained version range of ty will be used (e.g., >=0.0,<0.1).
no_project: boolAvoid discovering a project or workspace.
Instead of running checks in the context of the current project, run them in the context of the current directory. This is useful when the current directory is not a project.
installer: ResolverInstallerArgsbuild: BuildOptionsArgsrefresh: RefreshArgsTrait Implementations
Sourceimpl Args for CheckArgs
impl Args for CheckArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl FromArgMatches for CheckArgs
impl FromArgMatches for CheckArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
ArgMatches to self.Auto Trait Implementations
impl !Freeze for CheckArgs
impl RefUnwindSafe for CheckArgs
impl Send for CheckArgs
impl Sync for CheckArgs
impl Unpin for CheckArgs
impl UnsafeUnpin for CheckArgs
impl UnwindSafe for CheckArgs