pub type ConflictCheckedDependencyGroupsArgs = ProjectDependencyGroupsArgs<true>;Expand description
Dependency-group arguments for commands that reject conflicting extras or groups.
Aliased Type
pub struct ConflictCheckedDependencyGroupsArgs {
pub dev: bool,
pub no_dev: bool,
pub only_dev: bool,
pub group: Vec<GroupName>,
pub no_group: Vec<GroupName>,
pub no_default_groups: bool,
pub only_group: Vec<GroupName>,
pub all_groups: bool,
}Fields
dev: boolInclude the development dependency group [env: UV_DEV=]
Development dependencies are defined via dependency-groups.dev or
tool.uv.dev-dependencies in a pyproject.toml.
This option is an alias for --group dev.
This option is only available when running in a project.
no_dev: boolDisable the development dependency group [env: UV_NO_DEV=]
This option is an alias of --no-group dev.
See --no-default-groups to disable all default groups instead.
This option is only available when running in a project.
only_dev: boolOnly include the development dependency group.
The project and its dependencies will be omitted.
This option is an alias for --only-group dev. Implies --no-default-groups.
group: Vec<GroupName>Include dependencies from the specified dependency group.
May be provided multiple times.
no_group: Vec<GroupName>Disable the specified dependency group [env: UV_NO_GROUP=]
This option always takes precedence over default groups,
--all-groups, and --group.
May be provided multiple times.
no_default_groups: boolIgnore the default dependency groups.
uv includes the groups defined in tool.uv.default-groups by default.
This disables that option, however, specific groups can still be included with --group.
only_group: Vec<GroupName>Only include dependencies from the specified dependency group.
The project and its dependencies will be omitted.
May be provided multiple times. Implies --no-default-groups.
all_groups: boolInclude dependencies from all dependency groups.
--no-group can be used to exclude specific groups.